@@ -3,4 +3,4 @@ from .is_authenticated import IsAuthenticated
 from .is_staff import IsStaff
 from .has_permission import HasPermission
 from .is_member import IsMember
-from .token import TamarinTokenSerializer
+from .token import TamarinTokenSerializer, TamarinTokenObtainPairView
